==> laboro_demo-0.0.9.tar.gz: laboro_demo-0.0.9/src/laboro_demo/submodule/__init__.py <==
import logging
from laboro.module import Module


class SubDemo(Module):
  """This class is derived from the ``laboro.module.Module`` base class.

  Its purpose is to provide a demonstrator module that validate **Laboro** modules loading and class instantiation mechanisms.

  It also allow global testing on features common to any **Laboro** modules.

  Arguments:

    args: An optional dictionary representing all module args, their types and their values.
  """
  def __init__(self, args=None):
    super().__init__(filepath=__file__, args=args)

  def _is_a_demo(self):
    """Display a message according to the ``is_demo`` arguments given at init time.
    """
    is_demo = "is not"
    if self.get_arg_value("is_demo"):
      is_demo = "is"
    logging.info(f"This instance of the {self.__class__.__name__} is named {self.get_arg_value('name')} and {is_demo} a demonstration module.")

  def _display_list(self):
    """Display the content of the ``demo_list`` argument if  the ``list_only`` argument was set to *True* at init time.
    """
    if "list_only" in self.args:
      logging.info("The given list items are:")
      for item in self.get_arg_value("demo_list"):
        logging.info(f"  - {item}")

  def _display_dict(self):
    """Display the content of the ``demo_dict`` argument if the ``dict_only`` argument was set to *True* at init time.
    """
    if "dict_only" in self.args:
      logging.info("The given dict items key and values are:")
      for key, value in self.get_arg_value("demo_dict").items():
        logging.info(f"  - {key}: {value}")

  def _display_password(self):
    """Display the **redacted** content of the ``password`` argument given at init time.
    """
    logging.info(f"The following password should be redacted: {self.get_arg_value('password')}")

  def self_test(self):
    """Run all the private methods.
    """
    self._is_a_demo()
    self._display_list()
    self._display_dict()
    self._display_password()

  @Module.laboro_method
  def show_argument(self, argument, crumb):
    """Log the specified ``argument`` and the ``crumb`` value.

    Arguments:
      ``argument``: A string value specifying one of the argument given to ``__init__``.
      ``crumb``: Any value to be logged as its string representation.

    Raises:
      ``laboro.error.LaboroError``: Whenever the ``argument`` value is not a valid argument name.
    """
    arg_value = self.get_arg_value_as_string(argument)
    logging.info(f"This is a demo: {argument}: {arg_value} / crumb: {crumb}")

==> laboro_demo-0.0.12.tar.gz: laboro_demo-0.0.12/src/laboro_demo/submodule/__init__.py <==
import string
import random
import logging
from laboro.module import Module


class SubDemo(Module):
  """This class is derived from the ``laboro.module.Module`` base class.

  Its purpose is to provide a demonstrator module that validate **Laboro** modules loading and class instantiation mechanisms.

  It also allow global testing on features common to any **Laboro** modules.

  Arguments:

    args: An optional dictionary representing all module args, their types and their values.
  """
  def __init__(self, store, args=None):
    super().__init__(filepath=__file__, store=store, args=args)

  def _is_a_demo(self):
    """Display a message according to the ``is_demo`` arguments given at init time.
    """
    is_demo = "is not"
    if self.get_arg_value("is_demo"):
      is_demo = "is"
    logging.info(f"This instance of the {self.__class__.__name__} is named {self.get_arg_value('name')} and {is_demo} a demonstration module.")

  def _display_list(self):
    """Display the content of the ``demo_list`` argument if  the ``list_only`` argument was set to *True* at init time.
    """
    if "list_only" in self.args:
      logging.info("The given list items are:")
      for item in self.get_arg_value("demo_list"):
        logging.info(f"  - {item}")

  def _display_dict(self):
    """Display the content of the ``demo_dict`` argument if the ``dict_only`` argument was set to *True* at init time.
    """
    if "dict_only" in self.args:
      logging.info("The given dict items key and values are:")
      for key, value in self.get_arg_value("demo_dict").items():
        logging.info(f"  - {key}: {value}")

  def _display_password(self):
    """Display the **redacted** content of the ``password`` argument given at init time.
    """
    logging.info(f"The following password should be redacted: {self.get_arg_value('password')}")

  @Module.laboro_method
  def self_test(self):
    """Run all the private methods.
    """
    self._is_a_demo()
    self._display_list()
    self._display_dict()
    self._display_password()

  @Module.laboro_method
  def show_argument(self, argument, crumb):
    """Log the specified ``argument`` and the ``crumb`` value.

    Arguments:
      ``argument``: A string value specifying one of the argument given to ``__init__``.
      ``crumb``: Any value to be logged as its string representation.

    Raises:
      ``laboro.error.LaboroError``: Whenever the ``argument`` value is not a valid argument name.
    """
    arg_value = self.get_arg_value_as_string(argument)
    logging.info(f"This is a demo: {argument}: {arg_value} / crumb: {crumb}")

  @Module.laboro_method
  def get_random_data(self):
    logging.info("Generating random data structure")
    return ["".join(random.choices(string.ascii_uppercase, k=9)) for d in range(50)]
